#
# spec file for package mongodb
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _home_dir       %{_var}/lib/%{name}
%define _mongodb_user     %{name}
%define _mongodb_group    %{name}
%if 0%{?suse_version} > 1220
    %bcond_without systemd
%else
    %bcond_with systemd
%endif
%if %{?suse_version} >= 1500
%define scons_bin %{_bindir}/scons
%else
%define scons_bin buildscripts/scons.py
%endif
Name:           mongodb
Version:        3.6.8
Release:        pm151.4.5
Summary:        The MongoDB document-oriented database system (metapackage)
License:        AGPL-3.0-only
Group:          Productivity/Databases/Servers
URL:            http://www.mongodb.org
Source0:        https://fastdl.mongodb.org/src/mongodb-src-r%{version}.tar.gz
Source1:        mongodb.init
Source2:        mongodb.logrotate
Source3:        mongodb.conf
Source4:        mongodb.service
Source5:        mongodb-tmpfile
Patch0:         mongo-src-3.6.8-python3.patch
Patch1:         mongodb-3.6.8-fix-syntax.patch
# from https://sources.debian.org/patches/mongodb/1:3.4.18-2/fix-ftbfs-with-openssl-1.1.1.patch/
Patch2:         fix-ftbfs-with-openssl-1.1.1.patch
Patch3:         fix-abi-not-declared.patch
BuildRequires:  glibc-devel
BuildRequires:  libpcap-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  scons >= 2.3
BuildRequires:  snappy-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(yaml-cpp)
BuildRequires:  libboost_system-devel
Requires:       logrotate
Requires:       mongodb-mongoperf = %{version}
Requires:       mongodb-mongos = %{version}
Requires:       mongodb-server = %{version}
Requires:       mongodb-shell = %{version}
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Conflicts:      mongo-10gen-enterprise
Conflicts:      mongodb-enterprise
Conflicts:      mongodb-enterprise-unstable
Conflicts:      mongodb-org
Conflicts:      mongodb-org-unstable
ExcludeArch:    i586 ppc
# MongoDB (upstream) does NOT support PPC, PPC64 or PPC64LE
# on the 3.0.X series.
#
# MongoDB specifically recommends NOT
# building and using mongodb on PPC, including
# PPC64 and PPC64LE because it may, among
# other things, corrupt data. Compiling pure upstream
# mongodb also fails on PPC, PPC64 and PPC64LE.
#
# MongoDB is working and plans to support PPC64 and PPC64LE
# in the future.
#
# Leave PPC lines in spec file to make it (much) easier to enable
# PPC building when updating mongodb to newer version
# since they have been known to work and have been suggested by upstream
ExcludeArch:    ppc64 ppc64le
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
%endif
%if 0%{?sle_version} == 120200 || 0%{?sle_version} == 120300
BuildRequires:  gcc6
BuildRequires:  gcc6-c++
%else
BuildRequires:  gcc-c++ >= 5.3
%endif
%if 0%{?suse_version} >= 1500
BuildRequires:  python3-Cheetah3
BuildRequires:  python3-PyYAML
BuildRequires:  python3-regex
BuildRequires:  python3-setuptools
%else
BuildRequires:  python-Cheetah
BuildRequires:  python-PyYAML
BuildRequires:  python-regex
BuildRequires:  python-setuptools
BuildRequires:  python-typing
%endif
%ifarch ppc64 ppc64le
BuildRequires:  gperftools-devel
%endif
%if %{with systemd}
BuildRequires:  systemd
%{?systemd_requires}
%else
Requires(post): %insserv_prereq
Requires(pre):  %fillup_prereq
Requires(pre):  %insserv_prereq
%endif

%description
MongoDB is a document-oriented database program. Classified as a
NoSQL database program, MongoDB uses JSON-like documents with
schemas. It has auto-sharding, built-in replication, TTL indexes,
text search as well as an aggregation framework and native MapReduce.

This metapackage will install the mongo shell, import/export tools,
other client utilities, server software, default configuration, and
init.d scripts.

%package server
Summary:        Document-oriented database server
Group:          Productivity/Databases/Servers
Requires:       openssl
Requires:       shadow
Conflicts:      mongo-10gen-enterprise-server
Conflicts:      mongodb-enterprise-server
Conflicts:      mongodb-enterprise-unstable-server
Conflicts:      mongodb-org-server
Conflicts:      mongodb-org-unstable-server

%description server
MongoDB is a document-oriented database program. Classified as a
NoSQL database program, MongoDB uses JSON-like documents with
schemas. It has auto-sharding, built-in replication, TTL indexes,
text search as well as an aggregation framework and native MapReduce.

This package contains the MongoDB server software, default
configuration files, and service scripts.

%package shell
Summary:        MongoDB shell client
Group:          Productivity/Databases/Clients
Requires:       mongodb-server = %{version}
Requires:       openssl
Conflicts:      mongo-10gen-enterprise-shell
Conflicts:      mongodb-enterprise-shell
Conflicts:      mongodb-enterprise-unstable-shell
Conflicts:      mongodb-org-shell
Conflicts:      mongodb-org-unstable-shell

%description shell
MongoDB is a document-oriented database program. Classified as a
NoSQL database program, MongoDB uses JSON-like documents with
schemas. It has auto-sharding, built-in replication, TTL indexes,
text search as well as an aggregation framework and native MapReduce.

This package contains the mongo shell.

%package mongos
Summary:        MongoDB sharded cluster query router
Group:          Productivity/Databases/Tools
Conflicts:      mongo-10gen-enterprise-mongos
Conflicts:      mongodb-enterprise-mongos
Conflicts:      mongodb-enterprise-unstable-mongos
Conflicts:      mongodb-org-mongos
Conflicts:      mongodb-org-unstable-mongos

%description mongos
MongoDB is a document-oriented database program. Classified as a
NoSQL database program, MongoDB uses JSON-like documents with
schemas. It has auto-sharding, built-in replication, TTL indexes,
text search as well as an aggregation framework and native MapReduce.

This package contains mongos, the MongoDB sharded cluster query router.

%package mongoperf
Summary:        MongoDB utility to check disk I/O performance
Group:          Productivity/Databases/Tools
Conflicts:      mongo-10gen-enterprise-mongoperf
Conflicts:      mongodb-enterprise-mongoperf
Conflicts:      mongodb-enterprise-unstable-mongoperf
Conflicts:      mongodb-org-mongoperf
Conflicts:      mongodb-org-unstable-mongoperf

%description mongoperf
MongoDB is a document-oriented database program. Classified as a
NoSQL database program, MongoDB uses JSON-like documents with
schemas. It has auto-sharding, built-in replication, TTL indexes,
text search as well as an aggregation framework and native MapReduce.

This package contains mongoperf.

%clean
df -hTP

%prep
df -hTP
%autosetup -p1 -n mongodb-src-r%{version}

%build
# change default database path to reflect the default database user directory
sed -i 's|/data/db/|%{_home_dir}/|' src/mongo/db/storage/storage_options.cpp

%{scons_bin} \
%ifarch aarch64
    CCFLAGS="-march=armv8-a+crc" \
%endif
%if 0%{?sle_version} == 120200 || 0%{?sle_version} == 120300
    CC=%{_bindir}/gcc-6 CXX=%{_bindir}/g++-6 \
%endif
    core \
    %{?_smp_mflags} \
    --disable-warnings-as-errors \
    --nostrip \
    --ssl \
%ifarch x86_64  aarch64
    --wiredtiger=on \
%else
    --wiredtiger=off \
    --mmapv1=on \
%endif
%ifarch ppc64 ppc64le
    --js-engine=none \
    --allocator=system \
%endif
%if 0%{?suse_version} >= 1500
    --use-system-boost \
%endif
    --use-system-pcre \
    --use-system-snappy \
    --use-system-yaml \
    --use-system-zlib \

%install
%{scons_bin} \
%ifarch aarch64
    CCFLAGS="-march=armv8-a+crc" \
%endif
%if 0%{?sle_version} == 120200 || 0%{?sle_version} == 120300
    CC=%{_bindir}/gcc-6 CXX=%{_bindir}/g++-6 \
%endif
    install --prefix=%{buildroot}%{_prefix} \
    --disable-warnings-as-errors \
    --nostrip \
    --ssl \
%ifarch x86_64  aarch64
    --wiredtiger=on \
%else
    --wiredtiger=off \
    --mmapv1=on \
%endif
%ifarch ppc64 ppc64le
    --js-engine=none \
    --allocator=system \
%endif
%if 0%{?suse_version} >= 1500
    --use-system-boost \
%endif
    --use-system-pcre \
    --use-system-snappy \
    --use-system-yaml \
    --use-system-zlib \

mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/mongod %{buildroot}%{_sbindir}/mongod
mv %{buildroot}%{_bindir}/mongos %{buildroot}%{_sbindir}/mongos

mkdir -p %{buildroot}%{_var}/log/mongodb
mkdir -p %{buildroot}%{_var}/lib/mongodb

%if %{with systemd}
    install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
    install -D -p -m 0755 %{SOURCE1} %{buildroot}%{_sbindir}/rc%{name}
    install -d -m 0755 %{buildroot}%{_tmpfilesdir}/
    install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf
%else
    install -D -p -m 0755 %{SOURCE1} %{buildroot}%{_sysconfdir}/init.d/%{name}
    ln -sf %{_initddir}/%{name} %{buildroot}%{_sbindir}/rc%{name}
    mkdir -p %{buildroot}/run/%{pkg_name}
%endif

install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.conf

mkdir -p %{buildroot}%{_mandir}/man1/
install -p -m 0644 debian/mongod.1 %{buildroot}%{_mandir}/man1/
install -p -m 0644 debian/mongoperf.1 %{buildroot}%{_mandir}/man1/
install -p -m 0644 debian/mongos.1 %{buildroot}%{_mandir}/man1/
install -p -m 0644 debian/mongo.1 %{buildroot}%{_mandir}/man1/

%pre server
if ! %{_bindir}/id -g %{_mongodb_group} &>/dev/null; then
    %{_sbindir}/groupadd -r %{_mongodb_group}
fi
if ! %{_bindir}/id %{_mongodb_user} &>/dev/null; then
    %{_sbindir}/useradd -M -r -g %{_mongodb_group} \
        -d %{_home_dir} -s /bin/false \
        -c "MongoDB database admin" %{_mongodb_user} > /dev/null 2>&1
fi

%if %{with systemd}
    %{service_add_pre %{name}.service}
%endif

%post server
/sbin/ldconfig
%if %{with systemd}
    %tmpfiles_create %{_tmpfilesdir}/%{name}.conf
    %{service_add_post %{name}.service}
%else
    %{fillup_and_insserv -f %{name}}
%endif

%preun server
%if %{with systemd}
    %{service_del_preun %{name}.service}
%else
    %{stop_on_removal %{name}}
%endif

%postun server
/sbin/ldconfig
%if %{with systemd}
    %{service_del_postun %{name}.service}
%else
    %{restart_on_update %{name}}
    %insserv_cleanup
%endif

%files

%files server
%{_sbindir}/mongod
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sbindir}/rc%{name}
%{_mandir}/man1/mongod.1%{?ext_man}

%if %{with systemd}
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%ghost %dir /run/%{name}
%else
%{_sysconfdir}/init.d/%{name}
%endif
%attr(0750,mongodb,mongodb) %{_var}/log/%{name}
%attr(0750,mongodb,mongodb) %{_var}/lib/%{name}

%files shell
%{_bindir}/mongo
%{_bindir}/install_compass
%{_mandir}/man1/mongo.1%{?ext_man}

%files mongos
%{_sbindir}/mongos
%{_mandir}/man1/mongos.1%{?ext_man}

%files mongoperf
%{_bindir}/mongoperf
%{_mandir}/man1/mongoperf.1%{?ext_man}

# TODO:
# * /var/lib/[mongodb] is NOT a subvolume in default BTRFS setup,
# which means system snapper snapshots will include mongodb database files!
# this is an issue with any database that's not PostgreSQL

%changelog
* Thu Jan  9 2020 Jan Zerebecki <jzerebecki@suse.com>
- This is now unmantained as it is not possible to comply with upstreams new
  license for later versions (SSPL 1.0) on most hardware.
- BuildRequire libboost_system to fix build
- Add patch to fix build failure with newer OpenSSL
- Add patch to fix abi not declared error (problem wasn't there yet with Leap
  15.2)
* Sun Jan 20 2019 astieger@suse.com
- mongodb 3.6.8 (the last version licensed under AGPL-3.0):
  * Fix tailable cursor fail on getMore against a sharded cluster
  * Fix incorrect result from covered index with collated field
    when collation not involved in match or sort
  * Fix failure to drop a collection with long index names via
    rename under MMAPv1
  * Fix privileges on setFCV virtual namespace.
- includes changes from 3.6.7:
  * Use batch insert when migrating chunks
  * Fix error on aggregation with $out when Auditing is enabled
  * Fix mongoreplay tool thar always replayed to secondary
- includes changes from 3.6.6:
  * Fix UUIDCatalog inconsistencies when using mapReduce “replace”
    on a sharded output collection
  * Add syncSourceHost field to replSetGetStatus output
- includes changes from 3.6.5:
  * Fis segmentation fault when shard is started with --shardsvr
    before being added to a shard
  * Fix collMod interruption may cause invariant failure
  * Fix server crash on $changeStream with invalid resume token
- includes changes from 3.6.4:
  * Add sharding metadata refresh metrics section to serverStatus.
  * Fix segmentation fault converting ReplicaSet to Replicated
    Shard Cluster
  * Fix 3.6 drivers failing to communicate with 3.6 sharded
    clusters running at FCV 3.4.
  * SLES11 support removed
  * Fix currentOp output no longer returning threadId field
- includes changes from 3.6.3:
  * fix mongod crash on find with index and nested $and/$or.
  * fix CappedPositionLost failure when tailing oplog on secondary
  * fix "address already in use" when using --bind_ip localhost
- add mongodb-3.6.8-fix-syntax.patch fixing syntax in build scripts
- change mongo-src-3.6.2-python3.patch to
  mongo-src-3.6.8-python3.patch to include more python 3 fixes,
  including those only triggered when building with system libs
- Build with the system versions of the following libraries:
  boost, pcre, snappy, yaml, zlib
* Wed Jun  6 2018 mpluskal@suse.com
- Remove useless comment
* Mon Apr  9 2018 mardnh@gmx.de
- Adjust gcc-c++ BuildRequires. Leap15/SLE15 don't ship gcc6
- Run spec-cleaner
* Fri Apr  6 2018 boris@steki.net
- re-enable wiredtiger backend on aarch64 (bnc#1087307)
* Fri Mar 30 2018 boris@steki.net
- enable mmapv1 build on non x86_64 architectures (bnc#1087307)
* Fri Feb 23 2018 jacobwinski@gmail.com
- Update to version 3.6.2:
  * Security
    + The contents of {USER} needs to be escaped when querying for the groups using LDAP server
  * Sharding
    + Cleanup mongos write commands execution
    + Shard does not call config commit chunk migration command with majority writeConcern nor checks for writeConcern errors.
    + Do not clear the cached sharding filtering information on replication state changes
    + UUIDs may be absent from shard secondary local collections
    + Remove CatalogCache retrieval methods, which take StringData
    + Requiring replSet for shards breaks Queryable Backup
  * Replication
    + Remove TopologyCoordinator interface
    + CollectionCloner fails if collection is dropped between getMore calls
    + QueryPlanKilled (operation exceeded time limit) in $changeStream with updateLookup
    + Clarify the reason temporary unique collection names are made
    + Disallow operations on drop-pending collections through applyOps
    + initial_sync_drop_collection.js should wait for system to stablize after restarting node
    + Disable chaining in initial_sync_drop_collection.js
  * Aggregation
    + Aggregation text search returns text score even if it wasn’t requested when targeting multiple shards in a sharded cluster
    + DocumentSourceSort sorts array documents incorrectly if there is a non-simple collation
  * Storage
    + Libraries db/db_raii and db/s/sharding are directly cyclic
    + Always log renameCollections in our tests
    + Fix race in CompatibleFirstStress lock manager test
    + Remove IndexObserver
  * Operations
    + mongo shell failed to connect with 3.6 connection string SRV
  * Build and Packaging
    + Fix long link times on OS X by passing -no_deduplicate to the linker
    + MongoDB msi installer for Compass contains a typo
  * Internals
    + check that oplogTruncateAfterPoint is correct in PeriodicKillSecondaries hook
    + Reduce the number of iterations for the toggle_feature_compatibility.js workload
    + Add additional unittesting for CompatibleFirst policy
    + Powercycle - remove mongod.lock file for MMAPV1 test
    + Avoid dropping lock before cleaning up DocumentSourceCursor’s PlanExecutor
    + PID file permission on v3.6 make it not not monitorable using pid file
    + implicitly_retry_on_database_drop_pending.js calls tojson() inside of a loop
    + Disable the sharding Evergreen task on the Enterprise OS X 10.10 MMAPv1 builder
- Include changes from 3.6.1:
  * Sharding
    + Invariant failure on config server when inserting tag into config.tags
    + Force the recipient shard to refresh its metadata after migration commit
    + Primary queries using maxTimeMS cause temporary shard write unavailability if ExceededTimeLimit
    + Remove all usages of the default constructor of ScopedCollectionMetadata outside of MetadataManager
    + ShardingTest.checkUUIDsConsistentAcrossCluster can fail to see collection in config.cache.collections
    + setFCV on config server should only generate UUIDs for non-dropped sharded collections
    + A migration will simply report “Data transfer error” when we have rich error details on the destination shard that are logged but not returned to the user
    + Disallow users from creating new indexes in config.transactions
    + Improve multi thread performance for retryable writes
    + Enable sign range optimization for clusterTime
    + ShardingCatalogManager::getDatabasesForShard should check if query was successful
    + Mongos crashes on bulk inserts which size are slightly bigger than maxBsonObjectSize
    + “CommandNotFound: no such command” in mongodb logs on 3.6
  * Replication
    + Cancel catchup takeover if primary caught up according to heartbeats
    + Rollback can abort on long collection names.
    + $changeStream reports incorrect documentKey for unsharded collections that become sharded
    + Delete unused rollback code
    + ChangeStreams lookup_post_image.js test makes assumptions that don’t hold up in secondary read passthrough
    + fix typo in sync_tail.cpp fillWriterVectorsAndLastestSessionRecords()
    + do a second majority write on oldPrimary before committed read in read_committed_after_rollback.js
    + Do not use IDL on oldest oplog entry
  * Query
    + Add an invariant that DocumentSourceCloseCursor does not execute on a mongod for a sharded $changeStream
    + Arrays of certain NumberDecimals can trigger an invariant failure
    + $rename does not update value if existing “to” field has the same numeric value but different type.
    + Add deprecation warning to “snapshot” option on queries
  * Write Operations
    + Deprecate $atomic/isolated update option
    + Updates using a numeric path component may cause index entries not to be created
  * Aggregation
    + Test that mongos accepts a –timeZoneInfo parameter, and can correctly execute expressions using time zones
    + changeStream cursor is not returned on a mongos when the database does not exist.
  * Storage
    + remove SnapshotName class
    + Test that applyOps can clone admin.system.version preserving its UUID
    + return error if collMod provides a UUID that does not match the UUID of the collection specified
    + allow enableMajorityReadConcern=false to work
    + applyOps view creation should not assign UUID
    + oldest_timestamp should track the last applied time, during initial sync
  * Operations
    + Disallow removing the featureCompatibilityVersion document
  * Build and Packaging
    + install_compass experience on OSX needs improvement
    + Remove Type=forking from Debian SystemD service file
  * Tools
    + qa-dump-restore-archiving oplog_rollover_test.js
  * Internals
    + system_perf.yml: Use new DSI interface and cleanup
    + Add a version of retryable_writes_jscore_passthrough.yml with stepdowns
    + The mongod process forks before listening for connections
    + Bring BSONObj parsers back for IDL generated commands
    + UUIDs should be added to local collections for replica sets only on clean startup
    + HostAndPort for replSetInitiate() no longer finds hostname for localhost
    + WT performance regression with write retryability enabled
    + applyOps command with UUID containing op must require granular privileges
    + explain3.js should assert that its writes succeed
    + Improve signal given by list_local_sessions.js
    + Run test stage of sys-perf and mongo-perf failures should lead to red evergreen boxes
    + Require shard servers and config servers to be started with –replSet or ‘replSetName’
    + Migration of txn oplog entries can trigger fassert in secondary replication
    + Shell SRV implementation does not allow authSource from TXT records to be used
    + Revert erroneous high error codes
    + Evergreen tests broken in master
    + Implement Initial DNS Seedlist discovery spec
    + build.sh script doesn’t abort on error
    + qa-tests-unstable force_table_scan.js
    + qa-tests-unstable no_primary_error_code.js
    + qa-tests-unstable no_sharded_secondary_reads.js
    + Make sure eviction visits all trees
    + Cursor remove operation unpins page too early
    + Transactions with timestamps should read their writes
- Rebase existing python3 patch so it applies cleanly to 3.6.2:
  mongo-src-3.6.2-python3.patch
* Thu Feb 22 2018 jacobwinski@gmail.com
- Remove mongo-tools files, it is a seperate project
  here & upstream since 2015.
- Update _constraints make hardware memory 8G, fixes compile failure
* Mon Dec 25 2017 boris@steki.net
- on "older (supported...)" distribution scons is too old,
  use bundled version to make it build correct
* Fri Dec 22 2017 boris@steki.net
- updated to release 3.6.0
* Tue Dec  5 2017 boris@steki.net
- initial python3 port
* Thu Nov 16 2017 fcrozat@suse.com
- Add TasksMax and TasksAccounting to systemd service, based on
  upstream recommendation.
* Mon Nov 13 2017 fcrozat@suse.com
- Add tmpfiles file to create /var/run/mongodb at startup and use
  this directory to store PID file created by mongodb server. This
  ensure systemd forking monitor works as designed.
* Wed Nov  1 2017 astieger@suse.com
- MongoDB 3.4.10:
  * The networkMessageCompressors configuration setting (aka wire
    protocol compression), which is disabled by default, exposed a
    vulnerability when enabled that could be exploited by a
    malicious attacker to deny service or modify memory.
    CVE-2017-15535 bsc#1065956
  * Avoid G_X lock for rename_collection within database
  * View with collation doesn’t work as expected in sharded cluster
  * Calling shardCollection after enableSharding may fail if
    executed against different mongos
- includes changes from 3.4.9:
  * Sharding an existing small collection results in large number
    of chunks
  * Reduce calls to allocator for large $in expressions
  * RangeDeleter holds WT transaction open while waiting for
    majority
  * Range deleter assert failed because of replication lag
- includes changes from 3.4.7:
  * BSON Document Size can be exceeded when grouping inserts on
    SECONDARY nodes
  * Enable configuration of OpenSSL cipher suite via setParameter
  * Optimize incremental update performance of ChunkManager and
    CollectionMetadata
- includes changrs from 3.4.6:
  * Only close idle cached cursors on the WiredTiger ident that
    is busy.
  * $geoWithin in aggregation pipeline after $lookup and $unwind
    returns incorrect results.
  * Cursor opens should never block for the duration of a checkpoint.
- includes changes from 3.4.5:
  * Multikey indexes should not be eligible for DISTINCT_SCAN if
    distinct key is an array component.
  * GlobalLock with timeout can still block indefinitely.
  * mongos can segfault in getMore on views with find batchSize of
    0.
- includes changes from 3.4.4:
  * Add an aggregation operator $objectToArray to convert an object
    to an array of key, value pairs.
  * Add an aggregation operator $arrayToObject to convert an array
    of pairs to an object.
  * ChunkManager refresh can occasionally cause a full reload.
* Wed Apr 26 2017 idonmez@suse.com
- Use gcc6 on SLE >= 12SP2 and enable s390x port
* Fri Apr  7 2017 jengelh@inai.de
- Replace buzzword-rich description by something meaningful.
- Drop unused -devel subpackage.
* Thu Apr  6 2017 guoyunhebrave@gmail.com
- Exclude i586 build architecture.
* Wed Mar 29 2017 guoyunhebrave@gmail.com
- Update to version 3.4.3. Change log at https://docs.mongodb.com/manual/release-notes/3.4-changelog/
* Mon Dec 12 2016 plinnell@opensuse.org
- update to 3.2.11
  + detailed change log:
  https://docs.mongodb.com/manual/release-notes/3.2-changelog
* Thu Dec  1 2016 plinnell@suse.com
- add  Requires:  shadow - fixes build on SuseStudio
* Sat Sep 17 2016 rpm@fthiessen.de
- spec file cleanup
- Update to version 3.2.9
* Sat Jun  4 2016 jacobwinski@gmail.com
- Update to version 3.0.12:
  * Background index build may result in extra index key entries that do not correspond to indexed documents: SERVER-22970
  * Documents that contain embedded null characters can be created: SERVER-7005
  * IX GlobalLock being held while waiting for WiredTiger cache eviction: SERVER-22964
- Update to version 3.0.11:
  * For MongoDB 3.0.9 and MongoDB 3.0.10, during chunk migration, insert and update operations to documents in the migrating chunk are not reflected in the destination shard: SERVER-23425
- Update to version 3.0.10:
  * Read preference of secondaryPreferred can end up using unversioned connections: SERVER-18671
  * For MMAPv1 journaling, the “last sequence number” file (lsn file) may be ahead of what is synced to the data files: SERVER-22261.
  * Data size change for oplog deletes can overflow 32-bit int: SERVER-22634
  * High fragmentation on WiredTiger databases under write workloads: SERVER-22898.
- Update to version 3.0.9:
  * Queries which specify sort and batch size can return results out of order if documents are concurrently updated. SERVER-19996
  * Large amounts of create and drop collections can cause listDatabases to be slow under WiredTiger. SERVER-20961
  * Authentication failure message includes server IP address instead of the client IP address. SERVER-22054
- Updates to version 3.0.8:
  * findAndModify on mongos can upsert to the wrong shard. SERVER-20407.
  * WiredTiger commit visibility caused document not found. SERVER-21275.
  * The oplog can grow to 3x configured size. SERVER-21553
- Updates to version 3.0.7:
  * WiredTiger memory handling and performance issues: SERVER-20159, SERVER-20204, SERVER-20091, and SERVER-20176.
  * Reconfig during a pending step down may prevent a primary from stepping down: SERVER-20262.
  * Built-in roles requires additional privileges: SERVER-19131, SERVER-15893, and SERVER-13647.
- Updates to version 3.0.6:
  * WiredTiger Stability issues: SERVER-19751, SERVER-19673, and SERVER-19573.
  * Interaction between SSL and Auditing: SERVER-19538.
  * Aggregation $sort on sharded systems SERVER-19464.
- Update requirements to reflect upstream.
- Add proper Source file with URL.
- Cleanup spec file.
* Tue Aug  4 2015 jacobwinski@gmail.com
- Update to version 3.0.5.
- Drop mongodb-ssl-FIPS_mode_set.patch: fixed upstream.
- Drop most of mongo-tools, they are not a seperate project.
- Update spec file to reflect build, compilation and package requirements.
- Update mongodb.conf file to reflect new filetype:
  * all existing defaults were ported over to the new mongodb.conf
  * mongodb.conf file was based on the default upstream
  * old style conf file is still supported by MongoDB 3.0.5,
    but migration is recommended.
- Drop mongodb-2.4.11-ppc_patch_based_on_mongo_ibmsoe.patch due to incompatibilities:
  * MongoDB now uses the new WiredTiger storage engine. Newest IBM Power8 (PPC) patch:
    1) has not been updated for MongoDB 3.0.5
  2) pre-dates WiredTiger support
  3) upstream has already started to incorporate PPC64 support based on the IBM patchset
  * Therefore, to avoid major issues like data corruption and conflicts resulting from
    upstream already incorporating partial PPC64 supprt, this patch set has been dropped.
  * PPC64 is enabled using upstream code.
  * WARNING: quoting upstream: "Please note that MongoDB does no testing on Power8
    at this time, so this is definitely not a supported configuration."
- Drop mongodb-src-r2.4.12-no-werror.patch: no longer applies.
- Drop mongodb_2_4_10_add_js_engine_v8_3_14_option.patch: no longer valid
  as upstream now provides its own newer version of v8_3.XX
- Drop mongodb_2_4_10_import_v8_3_14_5_JS2C_Python_scripts.patch: no longer valid
  as upstream now provides its own Python scripts matching provided v8_3.XX
- Drop mongodb_2_4_10_update_v8_3_14_SConscript_for_ppc.patch: v8_3.14 no longer used.
- Enable WiredTiger on supported architectures:
  * quoting upstream: "WiredTiger as embedded in the MongoDB source tree
    does not currently support PPC64."
- Use upstream gperftool when possible:
  * "Changed in version 3.0.0: MongoDB uses a customized built-in version of tcmalloc
    to achieve significant performance gains. Building with --use-system-tcmalloc
    produces binaries that lack these performance gains."
- Update "ulimit" settings to recommended upstream in sysv & systemd files
* Wed Jun 24 2015 aplanas@suse.com
- Update to mongodb-2.4.14
  * Init script sets process ulimit to different value compared to
    documentation SERVER-17780
  * Compute BinData length in v8 SERVER-17647
  * Upgrade PCRE Version from 8.30 to Latest SERVER-17252
* Sun Jun 21 2015 bwiedemann@suse.com
- Enable IPv6 in default config (bnc#930566)
* Thu May 21 2015 aplanas@suse.com
- Remove `void_return.patch`
  * This patch is used only in SLE11 because a boost problem. Now
    mongodb is using a local copy of boost.
  * Also this patch avoid the deletion and repair of the database
    (bnc#738050)
* Wed Mar  4 2015 Led <ledest@gmail.com>
- update patches:
  * mongodb-2.4.11-ppc_patch_based_on_mongo_ibmsoe.patch
* Tue Mar  3 2015 Led <ledest@gmail.com>
- update version 2.4.13:
  * Security: Enforce BSON BinData length validation (SERVER-17278)
  * Security: Disable SSLv3 ciphers (SERVER-15673)
  * Networking: Improve BSON validation (SERVER-17264)
    (bnc#921759, CVE-2015-1609)
* Mon Mar  2 2015 Led <ledest@gmail.com>
- fix typo in changelog
* Sun Mar  1 2015 Led <ledest@gmail.com>
- fix typo is spec
* Sat Feb 28 2015 Led <ledest@gmail.com>
- Use systemd for openSUSE > 12.2
* Wed Feb 25 2015 Led <ledest@gmail.com>
- update version 2.4.12
- 2.4.12:
  * Sharding: Sharded connection cleanup on setup error can crash mongos
  * Sharding: "type 7" (OID) error when acquiring distributed lock
    for first time
  * Storage: explicitly zero .ns files on creation
  * Storage: partially written journal last section causes recovery to fail
- 2.4.11:
  * Indexes: Fixed issue that can cause index corruption when building
    indexes concurrently
  * Indexes: Fixed issue that can cause index corruption when shutting
    down secondary node during index build
  * Indexes: Mongod now recognizes incompatible "future" text and geo
    index versions and exits gracefully
  * Indexes: Fixed issue that can cause secondaries to fail replication
    when building the same index multiple times concurrently
  * Indexes: Fixed issue that can cause index corruption on the tenth
    index in a collection if the index build fails
  * Indexes: Introduced versioning for text and geo indexes to ensure
    backwards compatibility
  * Indexes: Disallowed building indexes on the system.indexes
    collection, which can lead to initial sync failure on secondaries
  * Sharding: Avoid frequent immediate balancer retries when config
    servers are out of sync
  * Sharding: Add indexes to locks collection on config servers to
    avoid long queries in case of large numbers of collections
  * Sharding: Fixed issue that can corrupt the config metadata cache
    when sharding collections concurrently
  * Sharding: Don’t move chunks created on collections with a hashed
    shard key if the collection already contains data
  * Replication: Fixed issue where node appears to be down in a replica
    set during a compact operation
  * Replication: Fixed issue that could cause delays in elections
    when a node is not vetoing an election
  * Replication: Step down all primaries if multiple primaries are
    detected in replica set to ensure correct election result
  * Replication: Upon clock skew detection, secondaries will switch
    to sync directly from the primary to avoid sync cycles
  * Runtime: The SIGXCPU signal is now caught and mongod writes a log
    message and exits gracefully
  * Runtime: Fixed issue where mongod fails to start on Linux when
    /sys/dev/block directory is not readable
  * GridFS: Chunk size is decreased to 255 KB (from 256 KB) to avoid
    overhead with usePowerOf2Sizes option
  * SNMP: Fixed MIB file validation under smilint
  * Shell: Fixed issue in V8 memory allocation that could cause
    long-running shell commands to crash
  * Shell: Fixed memory leak in the md5sumFile shell utility method
- remove patches:
  * mongodb-no-werror.patch
- add patches:
  * mongodb-src-r2.4.12-no-werror.patch
* Wed Feb 11 2015 normand@linux.vnet.ibm.com
- Add V8 3.14 in src/third_part/v8-3.14 used for opensuse >=13.2
- Add PowerPC specific patches based on two git trees:
  (only for ppc64 and ppc64le, not ppc)
  * https://github.com/ibmsoe/mongo
  * https://github.com/andrewlow/v8ppc
* Mon May  5 2014 bwiedemann@suse.com
- avoid hitting virtual memory limits with mmaps (bnc#876326)
* Mon Apr 21 2014 i@marguerite.su
- update version 2.4.10
  * Performs fast file allocation on Windows when available
  * Start elections if more than one primary is detected
  * Changes to allow safe downgrading from v2.6 to v2.4
  * Fixes for edge cases in index creation
- drop patch: mongodb-2.4.3-mongodb_scons-full-flag.patch, upstreamed
* Fri Feb 21 2014 speilicke@suse.com
- Fixed mongodb-2.4.3-mongodb_scons-full-flag.patch: i586 build broken
  due to path issues
* Thu Feb 13 2014 jsuchome@suse.cz
- tell logrotate about log file ownership (bnc#863719)
* Tue Oct 29 2013 speilicke@suse.com
- Simplify chmod'ing include headers
- Drop old include dirs from devel package
* Mon Oct 28 2013 speilicke@suse.com
- Disable -Werror where appropriate
- Build with system libraries: boost, pcre
- Drop v8 build conditional, it never had any effect anyway since this was the default
- Use in-tree v8 for now until someone wants to fix the fallout from
  different distro versions
* Wed Oct 16 2013 speilicke@suse.com
- Don't build with "-Wall", there far to many errors which just don't
  make sense to fix
* Mon Sep 16 2013 speilicke@suse.com
- Require scons >= 1.1.0, build will fail otherwise
* Wed Aug 21 2013 dvaleev@suse.com
- Disable building for BigEndian platforms
* Wed Aug 21 2013 dvaleev@suse.com
- don't enable service by default. It is up to user whether he
  wants to start the service automatically
* Fri May 24 2013 i@marguerite.su
- New upstream release 2.4.3
  * see http://docs.mongodb.org/manual/release-notes/2.4/
* Tue Apr 30 2013 dmueller@suse.com
- remove -o flag from useradd
  * useradd: -o flag is only allowed with the -u flag
* Fri Dec 21 2012 fcastelli@suse.com
- Ensure mongodb is started properly on NUMA machines
  (http://docs.mongodb.org/manual/administration/production-notes/#production-numa)
* Fri Nov 23 2012 mrueckert@suse.de
- use _home_dir define in the sed line
* Sat Sep 22 2012 i@marguerite.su
- New upstream release 2.2.0
  * see http://docs.mongodb.org/manual/release-notes/2.2/
- Remove deprecated_boost_functions.patch (Patch0)
  * upstream changed it as a warning.
- Regenerate void_return.patch (Patch1)
  * seems it aims to deal with the strange boost::filesystem::remove
- Drop mongodb-third_party.sm.py.patch (Patch2)
  * upstream rewrote its code, no its cpp instead of py.
- Drop mongodb-2.0.0_no_stupid_chmod.patch (Patch3)
  * no such code in SConstruct.
- Drop mongodb-src-r2.0.4_link_ssl.patch (Patch4)
  * upstream fixed.
- Drop mongodb_cxxflags.patch (Patch5)
  * not used at all.
- Fix i586 build.
  * mongodb-2.2.0-mongodb_scons-full-flag.patch
  * https://jira.mongodb.org/browse/SERVER-5575
* Fri Jul 20 2012 jengelh@inai.de
- Package /var/{lib,log}/mongodb, as they are needed for proper
  operation of the daemon which would otherwise refuse to start.
- Remove redundant sections from specfile
* Wed Apr 11 2012 simone.tolotti@gmail.com
- New upstream release 2.0.4
- Fixes (https://jira.mongodb.org/browse/SERVER/fixforversion/11107):
  * SERVER-5135 Journal compression ratio reporting is incorrect
  * SERVER-5177 fetching of docs in initial sync can assert
  * SERVER-5069 ~ScopedDBConnection is vague and somewhat misleading
* Thu Nov 17 2011 mrueckert@suse.de
- add back mongodb_cxxflags.patch
* Thu Nov 17 2011 mrueckert@suse.de
- added mongodb-src-r2.0.1_link_ssl.patch:
  Fix linking on factory. We need libcrypto in the library list
  there.
* Thu Nov 17 2011 mrueckert@suse.de
- fix build on sles. it didnt like some of our scons parameters
* Thu Nov 17 2011 mrueckert@suse.de
- update to 2.0.1
  - SERVER-3961 Segmentation Fault when creating new indexes
  - SERVER-4020 bad serverID set in setShardVersion
  - SERVER-3889 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to reset
    metadata
  - SERVER-3572 authenticate shouldn't use a write lock
  - SERVER-4091 rs.reconfig(...) on 1.8.4_rc0 causes server to exit
  - SERVER-3058 make sure distributed locks are thread-safe to
    acquire
  - SERVER-3683 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to
    stale/missing mongod metadata
  - SERVER-3594 new crash in 1.9.1: couldn't make room for new
    record (len: 135548) in capped ns <database>.system.profile
  - SERVER-3650 ReplicaSet rollback should use slaveOk
  - SERVER-3705 mongos not closing connections, filling up disk
    with logs
  - SERVER-3729 --ssl for tools
  - SERVER-3750 Need to limit size of backfilled elements when
    creating an array
  - SERVER-3619 mongostat can't authenticate to mongos using -u -p
    or the long name equivalents
  - SERVER-3605 After node is restarted it may not be set to ok
    state in mongos
  - SERVER-3666 mongod --auth must disable __system access
  - SERVER-3539 mongos returns duplicate "ns" element when you run
    db.xyz.stats()
  - SERVER-1097 mongoimport / export should adhere to CSV spec
  - SERVER-3462 slaveOk queries don't distribute to all secondaries
    when using a mongos
  - SERVER-2710 Running replSetReconfig while writing to a
    collection causes secondaries and arbiters to segfault.
  - SERVER-2976 add a pure JS mode to map reduce to get improved
    performance for light jobs
  - SERVER-3086 mongoexport only exports one shard's worth of data
  - SERVER-2872 mongos client/lasterror instability
  - SERVER-2792 replace readline with linenoise
  - SERVER-1503 rs priorities other than 0 and 1 not supported yet
  - SERVER-4196 Count command on mongos can get into infinite loop
  - SERVER-3683 Possible for setShardVersion to never be set on
    mongod after multiple StaleConfigExceptions due to
    stale/missing mongod metadata
  - SERVER-3529 Sharded map reduce using merge stalls recreating
    indexes on the output collection.
  - SERVER-3996 Backport fix for SERVER-3002 to v1.8 branch
- added optional switch to use libv8
- added mongodb-2.0.0_no_stupid_chmod.patch:
  dont do useless chmods
- minor spec file rework
* Mon Nov  7 2011 jmassaguerpla@suse.de
- added glibc-locale as a dependency
* Sun Nov  6 2011 jmassaguerpla@suse.de
- patched third-party/sm.py because of this bug
  http://scons.tigris.org/issues/show_bug.cgi?id=2800
* Thu Nov  3 2011 fcastelli@suse.com
- require libjs 1.7.0
* Fri Sep 30 2011 jw@suse.com
- made available also for SLE-11-SP1
* Wed Sep  7 2011 mrueckert@suse.de
- update to 1.8.3
  - [SERVER-3205] Dropping sharded database leads to errors with
    dbnames which are prefixes of dropped name
  - [SERVER-2707] make default stack size lower on linux
  - [SERVER-3507] Changing hostname in Replica Set configuration,
    does not affect rs.status(), until a server restart.
* Wed Sep  7 2011 mrueckert@suse.de
- added mongodb_werror.patch: drop -Werror from CFLAGS for building
  on older boost versions
* Wed Sep  7 2011 mrueckert@suse.de
- added b1ec2058673f8ca582a490c2dd4a8405698221ae.patch:
  patch taken from upstream git. adds detection code for linux3
* Wed Sep  7 2011 mrueckert@suse.de
- dont use PCH: it breaks build on SLE 11
* Wed Aug 17 2011 koprok@nand.bg
- Do not build libmongoclient.so shared library
* Mon Aug 15 2011 koprok@nand.bg
- Added -devel package with headers and static libraries
* Thu Aug 11 2011 mrueckert@suse.de
- update to 1.8.2
  - [SERVER-3188] CLONE - mongos crash with "Received signal 6"
  - [SERVER-1742] Assertion failure on mapreduce with geo query
  - [SERVER-3196] Segmentation Fault at startup on NUMA-Architecture
* Fri Apr 15 2011 mrueckert@suse.de
- update to 1.8.1
  - [SERVER-2324] compilation error with boost filesystem v3
  - [SERVER-2662] seg fault equivalent when query plan cannot
    recover from yield, does not assert, and is yielded again
  - [SERVER-2698] mongos seems to swallow 'No matching object
    found' errors when running findAndModify on a sharded
    collection.
  - [SERVER-2714] RS hidden setting should treat 1 as true
  - [SERVER-2719] mongod running as a service on Windows does not
    restart correctly after a reboot
  - [SERVER-2737] Large rollback fails (DR102 too much data written
    uncommitted) (after "rollback 6")
  - [SERVER-2762] backtrace of mongos crash
  - [SERVER-2787] Upgrading to 1.8.0 and enabling journaling
    causing cryptic "_a != -1" error
  - [SERVER-2791] missing write intent while initializing
    background index build job
  - [SERVER-2797] SEGV at BtreeCursor9prettyKey
  - [SERVER-2809] assertion in count / userquery op nscanned after
    failed yield recovery
  - [SERVER-2810] yield explain seg fault when accessing
    unprotected scan and order pointer
  - [SERVER-2815] DR102 on index creation w/dropDups + --journal
  - [SERVER-2853] Missing commitIfNeeded in background index build
  - [SERVER-2854] Unsafe to assert inside of CommitJob::note
  - [SERVER-2868] replica set connection gets confused about msater
  - [SERVER-2872] mongos client/lasterror instability
  - [SERVER-2808] when we get a seg fault (or similar) signal we
    should print the faulting address
- for the changes before see http://bit.ly/ga0jeH
- add /usr/sbin/usermod to the prereq
- respin mongodb_cxxflags.patch
* Tue Jan 18 2011 mhrusecky@suse.cz
- fixed build for openSUSE 11.2 (directory permissions)
* Tue Jan 18 2011 asn@cryptomilk.org
- Added missing build requirements for SLE
* Wed Jan 12 2011 asn@cryptomilk.org
- Added shared library to make binaries smaller.
- Added more comments to mongodb.conf
- Added support for CPPFLAGS.
- Don't strip the binaries for debuginfo packages.
* Mon Jan 10 2011 mhrusecky@suse.cz
- Using /etc/mongodb.conf instead of sysconfig
- Fixed init to run db as non-root
- Creating log and database directories in init script
- Added man pages
* Mon Jan  3 2011 asn@cynapses.org
- Added additional options
* Wed Dec 22 2010 asn@cynapses.org
- Fixed typo in mongodb init script.
* Wed Dec 22 2010 asn@cynapses.org
- Added a mongodb sysconfig file.
- Added localhost bind on startup.
- Added auth requirement on startup.
* Tue Dec 21 2010 asn@cynapses.org
- Silence mongodb daemon on startup.
* Tue Dec 21 2010 asn@cynapses.org
- Fixed logrotate requirement.
- Fixed the Group
* Tue Dec 21 2010 asn@cynapses.org
- Update to version 1.6.5
  * Attach a unique ID to moveChunk changelog entries
  * Check chunk boundaries of delete operations during chunk migration
  * Data loss after $set
  * replica sets connection safety
  * mongos doesn't pass mixed-case findAndModify
- Added a new working init script.
- Fixed directory permissions.
- Fixed spec file.
* Wed Oct 24 2001 jordimassaguerpla@gmail.com
- upgraded to mongodb 2.0.1
